@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.10.1;
 
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 
 
 1;
@@ -18,11 +18,11 @@ __END__
 
 =head1 NAME
 
-App::YTDL - Download C<YouTube> videos.
+App::YTDL - Download YouTube videos.
 
 =head1 VERSION
 
-Version 0.008
+Version 0.009
 
 =cut
 
@@ -36,19 +36,19 @@ Version 0.008
 
     yt-download -f|--file filename
 
-Channel C<ids> are needed to prefix with C<c#>, playlist C<ids> with C<p#>.
+Channel ids need a C<c#> prefix, playlist ids a C<p#> prefix.
 
 =head1 DESCRIPTION
 
-Download single C<YouTube> videos or/and choose videos from playlists or/and channels.
+Download single YouTube videos or/and choose videos from playlists or/and channels.
 
-For more info see L<yt-download> or call C<yt-download -h> and choose the option I<HELP>.
+For more info see L<yt-download> or call C<yt-download -h> and choose the option HELP.
 
 =head1 REQUIREMENTS
 
 It is required Perl version 5.10.1 or greater.
 
-See also the requirements mentioned in L<Term::Choose> respective in L<Term::Choose::Win32>.
+See also the requirements mentioned in L<Term::Choose> or in L<Term::Choose::Win32> if OS is MSWin32.
 
 =head1 AUTHOR
 
@@ -56,6 +56,8 @@ Kuerbis <cuer2s@gmail.com>
 
 =head1 CREDITS
 
+Essential parts of this application are using methods of the L<WWW::YouTube::Download> module.
+
 Thanks to the L<Perl-Community.de|http://www.perl-community.de> and the people form
 L<stackoverflow|http://stackoverflow.com> for the help.
 
